import { Component, forwardRef, OnChanges } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CustomInputComponent } from './../../_abstract/custom-input.component';

@Component({
	selector: 'app-checkbutton',
	templateUrl: './checkbutton.component.html',
	styleUrls: ['./checkbutton.component.scss'],
	providers: [
		{
			provide: NG_VALUE_ACCESSOR,
			useExisting: forwardRef(() => CheckbuttonComponent),
			multi: true
		}
	]
})
export class CheckbuttonComponent extends CustomInputComponent implements OnChanges {

	exposeMetaInTemplate: string[] = ['label', 'value', 'isDisabled'];

	isChecked: boolean;
	isDisabled = false;
	value?: string | boolean = true;
	currentValue: string | boolean;

	ngOnChanges() {
		this.isDisabled = this.meta.isDisabled;
	}

	private toggleChecked(e): void {
		e.target.blur();
		e.preventDefault();
		if (this.isDisabled) { return; }
		this.isChecked = !this.isChecked;
		this.currentValue = this.isChecked ? this.value : false;
		this.propagateChange(this.currentValue);
	}

	public writeValue(value: any): void {
		this.isChecked = value && value !== 0 && value !== 'false' ? value : false;
		this.currentValue = this.isChecked ? value : false;
	}
}
